@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2016, Phoronix Media
-	Copyright (C) 2008 - 2016, Michael Larabel
+	Copyright (C) 2008 - 2017, Phoronix Media
+	Copyright (C) 2008 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -42,6 +42,31 @@ class pts_client
 		chmod($lock_file, 0644);
 		return self::$lock_pointers[$lock_file] != false && flock(self::$lock_pointers[$lock_file], LOCK_EX | LOCK_NB);
 	}
+	public static function is_locked($lock_file)
+	{
+		$fp = fopen($lock_file, 'w');
+		$is_locked = $fp && !flock($fp, LOCK_EX | LOCK_NB);
+		$fp && fclose($fp);
+
+		return $is_locked;
+	}
+	public static function release_lock($lock_file)
+	{
+		// Remove lock
+		if(isset(self::$lock_pointers[$lock_file]) == false)
+		{
+			pts_file_io::unlink($lock_file);
+			return false;
+		}
+
+		if(is_resource(self::$lock_pointers[$lock_file]))
+		{
+			fclose(self::$lock_pointers[$lock_file]);
+		}
+
+		pts_file_io::unlink($lock_file);
+		unset(self::$lock_pointers[$lock_file]);
+	}
 	public static function init()
 	{
 		pts_core::init();
@@ -282,20 +307,21 @@ class pts_client
 	{
 		return (function_exists('posix_isatty') && posix_isatty(STDOUT)) || (PTS_IS_CLIENT && getenv('LS_COLORS'));
 	}
-	public static function cli_colored_text($str, $color)
+	public static function cli_colored_text($str, $color, $bold = false)
 	{
-		if(!self::supports_colored_text_output())
+		if(!self::supports_colored_text_output() || empty($color))
 		{
 			return $str;
 		}
 
+		$attribute = ($bold ? '1' : '0');
 		$colors = array(
-			'black' => '0;30',
-			'gray' => '1;30',
-			'blue' => '0;34',
-			'green' => '0;32',
-			'red' => '0;31',
-			'cyan' => '0;36',
+			'black' => $attribute . ';30',
+			'gray' => '1;30', // gray not bold doesn't look good in all consoles
+			'blue' => $attribute . ';34',
+			'green' => $attribute . ';32',
+			'red' => $attribute . ';31',
+			'cyan' => $attribute . ';36',
 			);
 
 		if(!isset($colors[$color]))
@@ -305,6 +331,15 @@ class pts_client
 
 		return "\033[" . $colors[$color] . 'm' . $str . "\033[0m";
 	}
+	public static function cli_just_bold($str)
+	{
+		if(!self::supports_colored_text_output())
+		{
+			return $str;
+		}
+
+		return "\033[1m$str\033[0m";
+	}
 	public static function save_test_result($save_to = null, $save_results = null, $render_graphs = true, $result_identifier = null)
 	{
 		// Saves PTS result file
@@ -1109,22 +1144,6 @@ class pts_client
 	{
 		return pts_config::read_bool_config('PhoronixTestSuite/Options/OpenBenchmarking/AnonymousUsageReporting', 0);
 	}
-	public static function release_lock($lock_file)
-	{
-		// Remove lock
-		if(isset(self::$lock_pointers[$lock_file]) == false)
-		{
-			return false;
-		}
-
-		if(is_resource(self::$lock_pointers[$lock_file]))
-		{
-			fclose(self::$lock_pointers[$lock_file]);
-		}
-
-		pts_file_io::unlink($lock_file);
-		unset(self::$lock_pointers[$lock_file]);
-	}
 	public static function check_command_for_function($option, $check_function)
 	{
 		$in_option = false;
@@ -1239,7 +1258,7 @@ class pts_client
 						trigger_error('Phoronix Test Suite Argument Missing.', E_USER_ERROR);
 					}
 
-					echo PHP_EOL . 'CORRECT SYNTAX:' . PHP_EOL . 'phoronix-test-suite ' . str_replace('_', '-', $command_alias) . ' ' . implode(' ', $argument_checks) . PHP_EOL . PHP_EOL;
+					echo PHP_EOL . pts_client::cli_just_bold('CORRECT SYNTAX:') . PHP_EOL . 'phoronix-test-suite ' . str_replace('_', '-', $command_alias) . ' ' . implode(' ', $argument_checks) . PHP_EOL . PHP_EOL;
 
 					if(method_exists($command, 'invalid_command'))
 					{
