@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2016, Phoronix Media
-	Copyright (C) 2009 - 2016, Michael Larabel
+	Copyright (C) 2009 - 2017, Phoronix Media
+	Copyright (C) 2009 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -56,6 +56,7 @@ class pts_test_run_manager
 	protected static $test_run_process_active = false;
 	protected $batch_mode = false;
 	protected $auto_mode = false;
+	public $DEBUG_no_test_execution_just_result_parse = false;
 
 	public function __construct($batch_mode = false, $auto_mode = false)
 	{
@@ -108,7 +109,7 @@ class pts_test_run_manager
 		{
 			static $last_run_count = 128; // just a number that should always cause the first check below to be true
 			static $run_std_devs;
-			$times_already_ran = $active_result_buffer->get_trial_run_count();
+			$times_already_ran = count($active_result_buffer->results);
 
 			if($times_already_ran <= $last_run_count)
 			{
@@ -359,11 +360,11 @@ class pts_test_run_manager
 			$hashes = array();
 			foreach($this->result_file->get_result_objects() as $result)
 			{
-				$hashes[] = $result->get_comparison_hash(false, false);
+				$hashes[] = $result->get_comparison_hash(true, false);
 			}
 			foreach($this->tests_to_run as &$run_request)
 			{
-				if($run_request instanceof pts_test_result && in_array($run_request->get_comparison_hash(false, false), $hashes))
+				if($run_request instanceof pts_test_result && in_array($run_request->get_comparison_hash(true, false), $hashes))
 				{
 					$no_repeated_tests = false;
 					break;
@@ -630,7 +631,13 @@ class pts_test_run_manager
 			return;
 		}
 
-		pts_test_execution::run_test($this, $test_run_request);
+		if($this->result_file instanceof pts_result_file && $this->result_file->has_matching_test_and_run_identifier($test_run_request, $this->get_results_identifier()))
+		{
+			// There already is a match for this test in this particular result buffer
+			return true;
+		}
+
+		$test_successful = pts_test_execution::run_test($this, $test_run_request);
 
 		if(pts_file_io::unlink(PTS_USER_PATH . 'halt-testing'))
 		{
@@ -648,68 +655,6 @@ class pts_test_run_manager
 			return false;
 		}
 
-		$test_successful = false;
-		if($test_run_request->test_profile->get_display_format() == 'NO_RESULT')
-		{
-			$test_successful = true;
-		}
-		else if($test_run_request instanceof pts_test_result && $test_run_request->active)
-		{
-			$end_result = $test_run_request->active->get_result();
-
-			// removed count($result) > 0 in the move to pts_test_result
-			if(count($test_run_request) > 0 && ((is_numeric($end_result) && $end_result > 0) || (!is_numeric($end_result) && isset($end_result[3]))))
-			{
-				pts_module_manager::module_process('__post_test_run_success', $test_run_request);
-				$test_identifier = $this->get_results_identifier();
-				$test_successful = true;
-
-				if(!empty($test_identifier))
-				{
-					$test_run_request->test_result_buffer = new pts_test_result_buffer();
-					$test_run_request->test_result_buffer->add_test_result($this->results_identifier, $test_run_request->active->get_result(), $test_run_request->active->get_values_as_string(), self::process_json_report_attributes($test_run_request), $test_run_request->active->get_min_result(), $test_run_request->active->get_max_result());
-					$this->result_file->add_result($test_run_request);
-
-					if($test_run_request->secondary_linked_results != null && is_array($test_run_request->secondary_linked_results))
-					{
-						foreach($test_run_request->secondary_linked_results as &$run_request_minor)
-						{
-							if(strpos($run_request_minor->get_arguments_description(), $test_run_request->get_arguments_description()) === false)
-							{
-								$run_request_minor->set_used_arguments_description($test_run_request->get_arguments_description() . ' - ' . $run_request_minor->get_arguments_description());
-								$run_request_minor->set_used_arguments($test_run_request->get_arguments() . ' - ' . $run_request_minor->get_arguments_description());
-							}
-
-							$run_request_minor->test_result_buffer = new pts_test_result_buffer();
-							$run_request_minor->test_result_buffer->add_test_result($this->results_identifier, $run_request_minor->active->get_result(), $run_request_minor->active->get_values_as_string(), self::process_json_report_attributes($test_run_request),$run_request_minor->active->get_min_result(), $run_request_minor->active->get_max_result());
-							$this->result_file->add_result($run_request_minor);
-						}
-					}
-
-					if($this->get_results_identifier() != null && $this->get_file_name() != null && pts_config::read_bool_config('PhoronixTestSuite/Options/Testing/SaveTestLogs', 'FALSE'))
-					{
-						static $xml_write_pos = 1;
-						pts_file_io::mkdir(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/test-logs/' . $xml_write_pos . '/');
-
-						if(is_dir(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/test-logs/active/' . $this->get_results_identifier()))
-						{
-							$test_log_write_dir = PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/test-logs/' . $xml_write_pos . '/' . $this->get_results_identifier() . '/';
-
-							if(is_dir($test_log_write_dir))
-							{
-								pts_file_io::delete($test_log_write_dir, null, true);
-							}
-
-							rename(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/test-logs/active/' . $this->get_results_identifier() . '/', $test_log_write_dir);
-						}
-						$xml_write_pos++;
-					}
-				}
-			}
-
-			pts_file_io::unlink(PTS_SAVE_RESULTS_PATH . $this->get_file_name() . '/test-logs/active/');
-		}
-
 		if($test_successful == false && $test_run_request->test_profile->get_identifier() != null)
 		{
 			$this->failed_tests_to_run[] = $test_run_request;
@@ -721,18 +666,21 @@ class pts_test_run_manager
 
 		return true;
 	}
-	protected static function process_json_report_attributes(&$test_run_request)
+	public static function process_json_report_attributes(&$test_run_request)
 	{
 		// XXX : add to attributes JSON here
 		$json_report_attributes = null;
 
-		if(($t = $test_run_request->test_profile->test_installation->get_compiler_data()))
+		if(is_object($test_run_request->test_profile->test_installation))
 		{
-			$json_report_attributes['compiler-options'] = $t;
-		}
-		if(($t = $test_run_request->test_profile->test_installation->get_install_footnote()))
-		{
-			$json_report_attributes['install-footnote'] = $t;
+			if(($t = $test_run_request->test_profile->test_installation->get_compiler_data()))
+			{
+				$json_report_attributes['compiler-options'] = $t;
+			}
+			if(($t = $test_run_request->test_profile->test_installation->get_install_footnote()))
+			{
+				$json_report_attributes['install-footnote'] = $t;
+			}
 		}
 		if(($t = $test_run_request->active->get_min_result()) != 0)
 		{
@@ -1285,8 +1233,7 @@ class pts_test_run_manager
 		if(!$this->auto_mode)
 		{
 			pts_client::$display->generic_heading('System Information');
-			echo 'Hardware:' . PHP_EOL . phodevi::system_hardware(true) . PHP_EOL . PHP_EOL;
-			echo 'Software:' . PHP_EOL . phodevi::system_software(true) . PHP_EOL . PHP_EOL;
+			echo phodevi::system_centralized_view() . PHP_EOL;
 		}
 
 		if(($this->prompt_save_results || $this->force_save_results) && count($this->tests_to_run) > 0) // or check for DO_NOT_SAVE_RESULTS == false
