@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2016, Phoronix Media
-	Copyright (C) 2008 - 2016, Michael Larabel
+	Copyright (C) 2008 - 2017, Phoronix Media
+	Copyright (C) 2008 - 2017, Michael Larabel
 	phodevi_cpu.php: The PTS Device Interface object for the CPU / processor
 
 	This program is free software; you can redistribute it and/or modify
@@ -52,6 +52,15 @@ class phodevi_cpu extends phodevi_device_interface
 			case 'scaling-governor':
 				$property = new phodevi_device_property('cpu_scaling_governor', phodevi::std_caching);
 				break;
+			case 'microcode-version':
+				$property = new phodevi_device_property('cpu_microcode_version', phodevi::smart_caching);
+				break;
+			case 'cache-size':
+				$property = new phodevi_device_property('cpu_cache_size', phodevi::smart_caching);
+				break;
+			case 'cache-size-string':
+				$property = new phodevi_device_property('cpu_cache_size_string', phodevi::smart_caching);
+				break;
 		}
 
 		return $property;
@@ -144,6 +153,26 @@ class phodevi_cpu extends phodevi_device_interface
 
 		return (is_numeric($node_count) && $node_count > 0 ? $node_count : 1);
 	}
+	public static function cpu_cache_size()
+	{
+		$cache_size = 0; // in KB
+
+		if(phodevi::is_linux())
+		{
+			$cache_size = self::cpuinfo_cache_size();
+		}
+		else if(phodevi::is_macosx())
+		{
+			$cache_size = phodevi_osx_parser::read_osx_system_profiler('SPHardwareDataType', 'L3Cache');
+
+			if(strpos($cache_size, ' MB'))
+			{
+				$cache_size = substr($cache_size, 0, strpos($cache_size, ' ')) * 1024;
+			}
+		}
+
+		return $cache_size;
+	}
 	public static function cpu_default_frequency_mhz()
 	{
 		return self::cpu_default_frequency() * 1000;
@@ -174,6 +203,21 @@ class phodevi_cpu extends phodevi_device_interface
 
 		return strpos($cpu, ' ') !== false && strpos($cpu, ' ') != strrpos($cpu, ' ') && pts_strings::has_in_istring($cpu, array('Intel', 'VIA', 'AMD', 'ARM', 'SPARC', 'Transmeta')) && stripos($cpu, 'unknown') === false;
 	}
+	public static function cpu_microcode_version()
+	{
+		$ucode_version = null;
+
+		if(is_readable('/sys/devices/system/cpu/cpu0/microcode/version'))
+		{
+			$ucode_version = pts_file_io::file_get_contents('/sys/devices/system/cpu/cpu0/microcode/version');
+		}
+		if(empty($ucode_version) && isset(phodevi::$vfs->cpuinfo))
+		{
+			$ucode_version = self::read_cpuinfo_line('microcode');
+		}
+
+		return $ucode_version;
+	}
 	public static function cpu_default_frequency($cpu_core = 0)
 	{
 		// Find out the processor frequency
@@ -585,6 +629,16 @@ class phodevi_cpu extends phodevi_device_interface
 			$cache_size = null;
 		}
 
+		return $cache_size;
+	}
+	public static function cpu_cache_size_string()
+	{
+		$cache_size = phodevi::read_property('cpu', 'cache-size');
+		if($cache_size > 1)
+		{
+			$cache_size .= ' KB';
+		}
+
 		return $cache_size;
 	}
 }
