@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2016, Phoronix Media
-	Copyright (C) 2008 - 2016, Michael Larabel
+	Copyright (C) 2008 - 2017, Phoronix Media
+	Copyright (C) 2008 - 2017, Michael Larabel
 	phodevi_system.php: The PTS Device Interface object for the system software
 
 	This program is free software; you can redistribute it and/or modify
@@ -566,9 +566,9 @@ class phodevi_system extends phodevi_device_interface
 				// GCC
 				// If it's a link, ensure that it's not linking to llvm/clang or something
 				$version = trim(shell_exec('gcc -dumpversion 2>&1'));
+				$v = shell_exec('gcc -v 2>&1');
 				if(pts_strings::is_version($version))
 				{
-					$v = shell_exec('gcc -v 2>&1');
 
 					if(($t = strrpos($v, $version . ' ')) !== false)
 					{
@@ -603,6 +603,15 @@ class phodevi_system extends phodevi_device_interface
 
 					$compilers['gcc'] = 'GCC ' . $version;
 				}
+				else if(($t = strpos($v, ' version ')) !== false)
+				{
+					$v = substr($v, ($t + strlen(' version ')));
+					if(($t = strpos($v, ' (')) !== false)
+					{
+						$v = substr($v, 0, $t);
+						$compilers['gcc'] = 'GCC ' . $v;
+					}
+				}
 			}
 		}
 
@@ -1590,9 +1599,16 @@ class phodevi_system extends phodevi_device_interface
 
 			if($renderer && ($s = strpos($renderer, 'Gallium')) !== false)
 			{
-				$renderer = substr($renderer, $s);
-				$renderer = substr($renderer, 0, strpos($renderer, ' ', strpos($renderer, '.')));
-				$info .= ' ' . $renderer . '';
+				$gallium = substr($renderer, $s);
+				$gallium = substr($gallium, 0, strpos($gallium, ' ', strpos($gallium, '.')));
+				$info .= ' ' . $gallium . '';
+			}
+
+			if($renderer && ($s = strpos($renderer, 'LLVM ')) !== false)
+			{
+				$llvm = substr($renderer, $s);
+				$llvm = substr($llvm, 0, strpos($llvm, ')'));
+				$info .= ' (' . $llvm . ')';
 			}
 		}
 
