@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2016, Phoronix Media
-	Copyright (C) 2009 - 2016, Michael Larabel
+	Copyright (C) 2009 - 2017, Phoronix Media
+	Copyright (C) 2009 - 2017, Michael Larabel
 	phodevi.php: The object for interacting with the PTS device framework
 
 	This program is free software; you can redistribute it and/or modify
@@ -272,6 +272,93 @@ class phodevi extends phodevi_base
 	{
 		return self::system_information_parse(self::available_software_components(), $return_as_string);
 	}
+	public static function system_centralized_view($return_as_string = true)
+	{
+		$core_count = phodevi::is_linux() ? phodevi_cpu::cpuinfo_core_count() : phodevi::read_property('cpu', 'core-count');
+		$thread_count = phodevi_cpu::cpuinfo_thread_count();
+
+		$sys = array(
+			'Processor' => phodevi::read_name('cpu'),
+				array(
+				'Core Count' => $core_count,
+				'Thread Count' => $core_count == $thread_count ? '' : $thread_count, // don't show thread count if it's same as core count
+				'Extensions' => phodevi_cpu::instruction_set_extensions(),
+			//	'Virtualization' => (phodevi_cpu::virtualization_technology() ? phodevi_cpu::virtualization_technology() : ''),
+				'Cache Size' => phodevi::read_property('cpu', 'cache-size-string'),
+				'Microcode'=> phodevi::read_property('cpu', 'microcode-version'),
+				'Scaling Driver'=> phodevi::read_property('cpu', 'scaling-governor'),
+				),
+			'Graphics' => phodevi::read_name('gpu'),
+				array(
+				'OpenGL' => phodevi::read_property('system', 'opengl-driver'),
+				'Vulkan' => phodevi::read_property('system', 'vulkan-driver'),
+				'OpenCL' => phodevi::read_property('system', 'opencl-driver'),
+				'Display Driver' => phodevi::read_property('system', 'display-driver-string'),
+				'Monitor' => phodevi::read_name('monitor'),
+				'Screen' => phodevi::read_property('gpu', 'screen-resolution-string'),
+				),
+			'Motherboard' => phodevi::read_name('motherboard'),
+				array(
+				'Memory' => phodevi::read_name('memory'),
+				'Chipset' => phodevi::read_name('chipset'),
+				'Audio' => phodevi::read_name('audoo'),
+				'Network' => phodevi::read_name('network'),
+				),
+			'Disk' => phodevi::read_name('disk'),
+				array(
+				'File-System' => phodevi::read_property('system', 'filesystem'),
+				'Mount Options' => phodevi::read_property('disk', 'mount-options-string'),
+				'Disk Scheduler' => phodevi::read_property('disk', 'scheduler'),
+				'Disk Details' => phodevi::read_property('disk', 'extra-disk-details'),
+				),
+			'Operating System' => phodevi::read_property('system', 'operating-system'),
+				array(
+				'Kernel' => phodevi::read_property('system', 'kernel-string'),
+				'Desktop' => phodevi::read_property('system', 'desktop-environment'),
+				'Display Server' => phodevi::read_property('system', 'display-server'),
+				'Compiler' => phodevi::read_property('system', 'compiler'),
+				'System Layer' => phodevi::read_property('system', 'system-layer'),
+				)
+			);
+
+		if($return_as_string)
+		{
+			$sys_string = null;
+			$tabled = array();
+			foreach($sys as $key => $in)
+			{
+				$space_in = 2;
+				if(is_array($in))
+				{
+					$tabled = array();
+					foreach($in as $key => $value)
+					{
+						if(!empty($value))
+						{
+							$tabled[] = array(pts_client::cli_just_bold($key) . ':' . str_repeat(' ', (16 - strlen($key))), $value);
+							//$sys_string .= '      ' . strtoupper($key) . ':' . $value . PHP_EOL;
+						}
+					}
+				}
+				else if(!empty($in))
+				{
+					if(!empty($tabled))
+					{
+						$sys_string .= pts_user_io::display_text_table($tabled, '    ', 0, 17) . PHP_EOL;
+					}
+					$sys_string .= PHP_EOL . '  ' . pts_client::cli_colored_text(strtoupper($key), 'gray', true) . ': ' . str_repeat(' ', (18 - strlen($key))) . pts_client::cli_colored_text($in, 'green', true) . PHP_EOL;
+				}
+
+			}
+			if(!empty($tabled))
+			{
+				$sys_string .= pts_user_io::display_text_table($tabled, '    ', 0, 17) . PHP_EOL;
+			}
+			return $sys_string;
+		}
+
+		return $sys;
+	}
 	public static function system_id_string()
 	{
 		$extra = null;
