@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2014 - 2016, Phoronix Media
-	Copyright (C) 2014 - 2016, Michael Larabel
+	Copyright (C) 2014 - 2017, Phoronix Media
+	Copyright (C) 2014 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -142,7 +142,8 @@ class phoromatic_server
 		}
 
 		// TODO XXX make this a rootadmin option or something
-		// self::$db->exec('PRAGMA synchronous = OFF');
+		self::$db->exec('PRAGMA journal_mode = WAL');
+		self::$db->exec('PRAGMA synchronous = NORMAL');
 
 		switch(self::read_database_version())
 		{
