@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2016, Phoronix Media
-	Copyright (C) 2008 - 2016, Michael Larabel
+	Copyright (C) 2008 - 2017, Phoronix Media
+	Copyright (C) 2008 - 2017, Michael Larabel
 	pho_graph.php: The core graph object that is used by the different graphing objects.
 
 	This program is free software; you can redistribute it and/or modify
@@ -71,6 +71,7 @@ abstract class pts_graph_core
 		$this->i['top_end_bottom'] = 22;
 		$this->i['mark_count'] = 6; // Number of marks to make on vertical axis
 		$this->i['multi_way_comparison_invert_default'] = true;
+		$this->i['support_color_branding'] = true;
 		$this->i['notes'] = array();
 
 		// Reset of setup besides config
@@ -129,6 +130,10 @@ abstract class pts_graph_core
 		{
 			$this->i['multi_way_comparison_invert_default'] = $extra_attributes['multi_way_comparison_invert_default'];
 		}
+		if(isset($extra_attributes['no_color_branding']))
+		{
+			$this->i['support_color_branding'] = false;
+		}
 
 		$this->test_result = &$result_object;
 
@@ -384,17 +389,22 @@ abstract class pts_graph_core
 	}
 	protected function identifier_to_branded_color($identifier, $fallback_color = null)
 	{
+		if($this->i['support_color_branding'] == false || !isset($identifier[6]))
+		{
+			return $fallback_color;
+		}
+
 		// See if the result identifier matches something to be color-coded better
 		$identifier = strtolower($identifier) . ' ';
 		if(strpos($identifier, 'geforce') !== false || strpos($identifier, 'nvidia') !== false || strpos($identifier, 'quadro') !== false)
 		{
 			$paint_color = '#77b900';
 		}
-		else if(strpos($identifier, 'radeon') !== false || strpos($identifier, 'amd ') !== false || strpos($identifier, 'opteron ') !== false || strpos($identifier, 'fx-') !== false || strpos($identifier, 'firepro ') !== false)
+		else if(strpos($identifier, 'radeon') !== false || strpos($identifier, 'amd ') !== false || strpos($identifier, 'a10-') !== false || strpos($identifier, 'opteron ') !== false || strpos($identifier, 'fx-') !== false || strpos($identifier, 'firepro ') !== false || strpos($identifier, 'ryzen ') !== false)
 		{
 			$paint_color = '#f1052d';
 		}
-		else if(strpos($identifier, 'intel ') !== false || strpos($identifier, 'xeon ') !== false || strpos($identifier, 'core i') !== false || strpos($identifier, 'celeron') !== false)
+		else if(strpos($identifier, 'intel ') !== false || strpos($identifier, 'xeon ') !== false || strpos($identifier, 'core i') !== false || strpos($identifier, 'pentium') !== false || strpos($identifier, 'celeron') !== false)
 		{
 			$paint_color = '#0b5997';
 		}
@@ -484,7 +494,7 @@ abstract class pts_graph_core
 				}
 				else
 				{
-					$longest_identifier_width = self::text_string_width($longest_identifier, $this->i['identifier_size']) + 8;
+					$longest_identifier_width = ceil(self::text_string_width($longest_identifier, $this->i['identifier_size']) * 1.065) + 10;
 				}
 
 				$longest_identifier_max = ($this->i['graph_width'] * 0.5) + 0.01;
@@ -525,9 +535,15 @@ abstract class pts_graph_core
 				{
 					$longest_string = explode(' - ', $longest_identifier);
 					$longest_string = pts_strings::find_longest_string($longest_string);
-
 					$rotated_text = round(self::text_string_width($longest_string, $this->i['identifier_size']) * 0.96);
-					$per_identifier_height = max((14 + (14 * count($this->results))), $rotated_text);
+					$per_identifier_height = 26; // default
+
+					if(ceil($rotated_text * 1.25) >= floor($per_identifier_height * count($this->results)))
+					{
+						// this is to avoid having a rotated text bar overrun other results
+						// XXX the 50 number might be too hacky
+						$per_identifier_height = max(54, ceil($rotated_text / count($this->results) * 1.1));
+					}
 				}
 				else if(count($this->results) > 3)
 				{
@@ -557,8 +573,7 @@ abstract class pts_graph_core
 					}
 				}
 
-
-				$num_identifiers = $this->test_result->test_result_buffer->get_count();
+				$num_identifiers = $this->test_result->test_result_buffer->get_count() + ($this->is_multi_way_comparison ? 2 : 0);
 				$this->i['graph_top_end'] = $this->i['top_start'] + ($num_identifiers * $per_identifier_height);
 				// $this->i['top_end_bottom']
 				$this->i['graph_height'] = $this->i['graph_top_end'] + 25 + $bottom_heading;
@@ -640,7 +655,7 @@ abstract class pts_graph_core
 				}
 			}
 
-			$this->svg_dom->add_text_element($this->graph_title, array('x' => 6, 'y' => (self::$c['size']['headers'] + 2), 'font-size' => self::$c['size']['headers'], 'fill' => self::$c['color']['background'], 'text-anchor' => 'start', 'xlink:show' => 'new', 'xlink:href' => $href));
+			$this->svg_dom->add_text_element($this->graph_title, array('x' => 6, 'y' => (self::$c['size']['headers'] + 2), 'font-size' => self::$c['size']['headers'], 'fill' => self::$c['color']['background'], 'text-anchor' => 'start', 'xlink:show' => 'new', 'xlink:href' => $href, 'font-weight' => 'bold'));
 
 			foreach($this->graph_sub_titles as $i => $sub_title)
 			{
@@ -651,7 +666,7 @@ abstract class pts_graph_core
 					while(self::text_string_width($sub_title, $sub_title_size) > ($this->i['graph_left_end'] - 20))
 						$sub_title_size -= 0.5;
 				}
-				$this->svg_dom->add_text_element($sub_title, array('x' => 6, 'y' => $vertical_offset, 'font-size' => $sub_title_size, 'fill' => self::$c['color']['background'], 'text-anchor' => 'start'));
+				$this->svg_dom->add_text_element($sub_title, array('x' => 6, 'y' => $vertical_offset, 'font-size' => $sub_title_size, 'font-weight' => 'bold', 'fill' => self::$c['color']['background'], 'text-anchor' => 'start'));
 			}
 
 			// SVG version of PTS thanks to https://gist.github.com/xorgy/65c6d0e87757dbb56a75
@@ -706,12 +721,12 @@ abstract class pts_graph_core
 		if($this->i['graph_orientation'] == 'HORIZONTAL' || $this->i['iveland_view'])
 		{
 			$g = $this->svg_dom->make_g(array('stroke' => self::$c['color']['notches'], 'stroke-width' => 1));
-			$this->svg_dom->add_element('line', array('x1' => ($left_start + 0.5), 'y1' => $top_start, 'x2' => ($left_start + 0.5), 'y2' => ($top_end + 1)), $g);
-			$this->svg_dom->add_element('line', array('x1' => $left_start, 'y1' => ($top_end + 0.5), 'x2' => ($left_end + 1), 'y2' => ($top_end + 0.5)), $g);
+			$this->svg_dom->add_element('line', array('x1' => $left_start, 'y1' => $top_start, 'x2' => $left_start, 'y2' => ($top_end + 1)), $g);
+			$this->svg_dom->add_element('line', array('x1' => $left_start, 'y1' => $top_end, 'x2' => ($left_end + 1), 'y2' => $top_end), $g);
 
 			if(!empty(self::$c['text']['watermark']))
 			{
-				$this->svg_dom->add_text_element(self::$c['text']['watermark'], array('x' => $left_end, 'y' => ($top_start - 5), 'font-size' => 7, 'fill' => self::$c['color']['text'], 'text-anchor' => 'end', 'xlink:show' => 'new', 'xlink:href' => self::$c['text']['watermark_url']));
+				$this->svg_dom->add_text_element(self::$c['text']['watermark'], array('x' => $left_end, 'y' => ($top_start - 5), 'font-size' => 8, 'fill' => self::$c['color']['text'], 'text-anchor' => 'end', 'xlink:show' => 'new', 'xlink:href' => self::$c['text']['watermark_url']));
 			}
 		}
 		else
@@ -772,7 +787,7 @@ abstract class pts_graph_core
 				}
 			}
 
-			$this->svg_dom->add_text_element($str, array('x' => ($left_start + $offset), 'y' => ($top_start - 5), 'font-size' => 7, 'fill' => self::$c['color']['text'], 'text-anchor' => 'start'));
+			$this->svg_dom->add_text_element($str, array('x' => ($left_start + $offset), 'y' => ($top_start - 5), 'font-size' => 8, 'fill' => self::$c['color']['text'], 'text-anchor' => 'start'));
 		}
 	}
 	protected function render_graph_value_ticks($left_start, $top_start, $left_end, $top_end, $show_numbers = true)
@@ -792,9 +807,9 @@ abstract class pts_graph_core
 
 				if($i != 0)
 				{
-					$show_numbers && $this->svg_dom->add_text_element($display_value, array('x' => $px_from_left + 2.5, 'y' => ($top_end + 5 + self::$c['size']['tick_mark'])), $g);
-					$this->svg_dom->add_element('line', array('x1' => ($px_from_left + 2.5), 'y1' => ($top_start), 'x2' => ($px_from_left + 2.5), 'y2' => ($top_end - 5), 'stroke-dasharray' => '5,5'), $g_lines);
-					$this->svg_dom->add_element('line', array('x1' => ($px_from_left + 2.5), 'y1' => ($top_end - 4), 'x2' => ($px_from_left + 2.5), 'y2' => ($top_end + 5)), $g_lines);
+					$show_numbers && $this->svg_dom->add_text_element($display_value, array('x' => $px_from_left + 2, 'y' => ($top_end + 5 + self::$c['size']['tick_mark'])), $g);
+					$this->svg_dom->add_element('line', array('x1' => ($px_from_left + 2), 'y1' => ($top_start), 'x2' => ($px_from_left + 2), 'y2' => ($top_end - 5), 'stroke-dasharray' => '5,5'), $g_lines);
+					$this->svg_dom->add_element('line', array('x1' => ($px_from_left + 2), 'y1' => ($top_end - 4), 'x2' => ($px_from_left + 2), 'y2' => ($top_end + 5)), $g_lines);
 				}
 
 				$display_value += $increment;
@@ -819,15 +834,15 @@ abstract class pts_graph_core
 
 				if($i != 0)
 				{
-					$show_numbers && $this->svg_dom->add_text_element($display_value, array('x' => ($px_from_left_start - 4), 'y' => round($px_from_top + (self::$c['size']['tick_mark'] / 2)) + 0.5), $g_text);
+					$show_numbers && $this->svg_dom->add_text_element($display_value, array('x' => ($px_from_left_start - 4), 'y' => round($px_from_top + (self::$c['size']['tick_mark'] / 2))), $g_text);
 
 					if($this->i['show_background_lines'])
 					{
-						$this->svg_dom->add_element('line', array('x1' => ($px_from_left_end + 6), 'y1' => ($px_from_top + 1.5), 'x2' => ($this->i['graph_left_end']), 'y2' => ($px_from_top + 1.5)), $g_background_lines);
+						$this->svg_dom->add_element('line', array('x1' => ($px_from_left_end + 6), 'y1' => ($px_from_top + 1), 'x2' => ($this->i['graph_left_end']), 'y2' => ($px_from_top + 1)), $g_background_lines);
 					}
 
-					$this->svg_dom->add_element('line', array('x1' => ($left_start), 'y1' => ($px_from_top + 1.5), 'x2' => ($left_end), 'y2' => ($px_from_top + 1.5)), $g_lines);
-					$this->svg_dom->add_element('line', array('x1' => ($left_start - 4), 'y1' => ($px_from_top + 1.5), 'x2' => ($left_start + 4), 'y2' => ($px_from_top + 1.5)), $g_lines_2);
+					$this->svg_dom->add_element('line', array('x1' => ($left_start), 'y1' => ($px_from_top + 1), 'x2' => ($left_end), 'y2' => ($px_from_top + 1)), $g_lines);
+					$this->svg_dom->add_element('line', array('x1' => ($left_start - 4), 'y1' => ($px_from_top + 1), 'x2' => ($left_start + 4), 'y2' => ($px_from_top + 1)), $g_lines_2);
 				}
 
 				$display_value += $increment;
@@ -851,7 +866,7 @@ abstract class pts_graph_core
 
 		$this->i['key_line_height'] = 16;
 		$ak = array_keys($this->results);
-		$this->i['key_item_width'] = 16 + self::text_string_width(pts_strings::find_longest_string($ak), self::$c['size']['key']);
+		$this->i['key_item_width'] = 20 + self::text_string_width(pts_strings::find_longest_string($ak), self::$c['size']['key']);
 		$this->i['keys_per_line'] = max(1, floor(($this->i['graph_left_end'] - $this->i['left_start']) / $this->i['key_item_width']));
 
 		return ceil(count($this->results) / $this->i['keys_per_line']) * $this->i['key_line_height'];
@@ -867,7 +882,7 @@ abstract class pts_graph_core
 
 		$i = 0;
 		$g_rect = $this->svg_dom->make_g(array('stroke' => self::$c['color']['notches'], 'stroke-width' => 1));
-		$g_text = $this->svg_dom->make_g(array('font-size' => self::$c['size']['key'], 'text-anchor' => 'start'));
+		$g_text = $this->svg_dom->make_g(array('font-size' => self::$c['size']['key'], 'text-anchor' => 'start', 'font-weight' => 'bold'));
 
 		if(!is_array($this->results))
 		{
@@ -916,9 +931,9 @@ abstract class pts_graph_core
 			$arrow_length_half = $arrow_length / 2;
 
 			$arrow_points = array(
-				$tip_x1 + 0.5 . ',' . $tip_y1,
-				$tail_x1 + 0.5 . ',' . ($tail_y1 + $arrow_length_half),
-				$tail_x1 + 0.5. ',' . ($tail_y1 - $arrow_length_half)
+				$tip_x1 . ',' . $tip_y1,
+				$tail_x1 . ',' . ($tail_y1 + $arrow_length_half),
+				$tail_x1 . ',' . ($tail_y1 - $arrow_length_half)
 				);
 		}
 
