@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2016, Phoronix Media
-	Copyright (C) 2010 - 2016, Michael Larabel
+	Copyright (C) 2010 - 2017, Phoronix Media
+	Copyright (C) 2010 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ class pts_openbenchmarking
 	}
 	public static function valid_user_name()
 	{
-		$invalid_users = array('pts', 'phoronix', 'local');
+		$invalid_users = array('pts', 'phoronix', 'local', 'official');
 		// TODO: finish function
 	}
 	public static function stats_software_list()
@@ -130,6 +130,7 @@ class pts_openbenchmarking
 			$composite_xml = $json_response['openbenchmarking']['result']['composite_xml'];
 
 			$result_file = new pts_result_file($composite_xml);
+			$result_file->set_reference_id($id);
 			//$id = strtolower($id);
 			$valid = $return_xml ? $result_file->get_xml() : pts_client::save_test_result($id . '/composite.xml', $result_file->get_xml(), true);
 
