@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2016, Phoronix Media
-	Copyright (C) 2010 - 2016, Michael Larabel
+	Copyright (C) 2010 - 2017, Phoronix Media
+	Copyright (C) 2010 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -91,7 +91,7 @@ class pts_result_file_output
 		}
 
 		$csv_output .= PHP_EOL;
-		$csv_output .= ' ';
+		$csv_output .= ' ' . $delimiter;
 
 		foreach($columns as $column)
 		{
@@ -110,6 +110,8 @@ class pts_result_file_output
 				$csv_output .= '"' . $result_object->test_profile->get_identifier() . ' - ' . $result_object->get_arguments() . '"';
 			}
 
+			$csv_output .= $delimiter . $result_object->test_profile->get_result_proportion();
+
 			foreach($columns as $column)
 			{
 				$buffer_item = $result_object->test_result_buffer->find_buffer_item($column);
@@ -195,7 +197,8 @@ class pts_result_file_output
 
 					if(is_numeric($val))
 					{
-						$result_output .= str_repeat(' ', $longest_result - strlen($val))  . '|';
+						$repeat_length = $longest_result - strlen($val);
+						$result_output .= ($repeat_length >= 0 ? str_repeat(' ', $repeat_length) : null)  . '|';
 						$current_line_length = strlen(substr($result_output, strrpos($result_output, PHP_EOL) + 1)) + 1;
 						$result_output .= str_repeat('=', round(($val / $max_value) * ($terminal_width - $current_line_length)));
 
@@ -254,7 +257,7 @@ class pts_result_file_output
 			$pdf->Ln(100);
 			$pdf->ImageJPGInline($output, 50, 40 + (($placement - 1) * 120), 120);
 
-			if($placement == 2)
+			if($placement == 2 || $result_object->test_result_buffer->get_count() > 12)
 			{
 				$placement = 0;
 				if($i != count($results))
@@ -265,6 +268,7 @@ class pts_result_file_output
 			$placement++;
 			$i++;
 		}
+		$pdf->WriteText('This file was automatically generated via the Phoronix Test Suite open-source benchmarking software.');
 		ob_get_clean();
 		$pdf->Output($dest, $output_name);
 	}
