@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2016, Phoronix Media
-	Copyright (C) 2008 - 2016, Michael Larabel
+	Copyright (C) 2008 - 2017, Phoronix Media
+	Copyright (C) 2008 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -32,7 +32,8 @@ class pts_test_result
 	public $test_result_buffer;
 
 	public $active = null;
-	public $secondary_linked_results = null;
+	public $generated_result_buffers = null;
+	public $test_run_times = null;
 
 	// Added to make it easy to have PTS modules run a custom binary prior to running a program for the test
 	public $exec_binary_prepend = null;
@@ -42,6 +43,7 @@ class pts_test_result
 	{
 		$this->test_profile = clone $test_profile;
 		$this->result = 0;
+		$this->test_run_times = array();
 	}
 	public function __clone()
 	{
@@ -60,6 +62,13 @@ class pts_test_result
 	{
 		$this->used_arguments_description = $arguments_description;
 	}
+	public function append_to_arguments_description($arguments_description)
+	{
+		if(strpos(' ' . $this->used_arguments_description . ' ', ' ' . $arguments_description . ' ') === false)
+		{
+			$this->used_arguments_description .= ($this->used_arguments_description != null ? ' ' : null) . $arguments_description;
+		}
+	}
 	public function set_result_precision($precision = 2)
 	{
 		$this->result_precision = $precision;
@@ -95,7 +104,7 @@ class pts_test_result
 				// this removal is done since the zz segment should be maintainable between comparisons
 				$tp = substr($tp, 0, $x);
 			}
-			return pts_test_profile::generate_comparison_hash($tp, $this->get_arguments(), $this->get_arguments_description(), $this->test_profile->get_app_version(), $raw_output);
+			return pts_test_profile::generate_comparison_hash($tp, $this->get_arguments(), $this->get_arguments_description(), $this->test_profile->get_app_version(), $this->test_profile->get_result_scale(), $raw_output);
 		}
 		else
 		{
@@ -172,6 +181,38 @@ class pts_test_result
 
 		return $largest_variation;
 	}
+	public function get_result_first()
+	{
+		// a.k.a. the result winner
+		$winner = null;
+
+		if($this->test_profile->get_result_proportion() == 'LIB')
+		{
+			$winner = $this->test_result_buffer->get_min_value(true);
+		}
+		else if($this->test_profile->get_result_proportion() == 'HIB')
+		{
+			$winner = $this->test_result_buffer->get_max_value(true);
+		}
+
+		return $winner;
+	}
+	public function get_result_last()
+	{
+		// a.k.a. the result loser
+		$winner = null;
+
+		if($this->test_profile->get_result_proportion() == 'HIB')
+		{
+			$winner = $this->test_result_buffer->get_min_value(true);
+		}
+		else if($this->test_profile->get_result_proportion() == 'LIB')
+		{
+			$winner = $this->test_result_buffer->get_max_value(true);
+		}
+
+		return $winner;
+	}
 	public function normalize_buffer_values($normalize_against = false)
 	{
 		if($this->test_profile->get_display_format() != 'BAR_GRAPH') // BAR_ANALYZE_GRAPH is currently unsupported
@@ -188,13 +229,14 @@ class pts_test_result
 			foreach($keys as $k)
 			{
 				$identifier_r = pts_strings::trim_explode(': ', $this->test_result_buffer->buffer_items[$k]->get_result_identifier());
+				$position = 1;
 
-				if(!isset($key_sets[$identifier_r[0]]))
+				if(!isset($key_sets[$identifier_r[$position]]))
 				{
-					$key_sets[$identifier_r[0]] = array();
+					$key_sets[$identifier_r[$position]] = array();
 				}
 
-				$key_sets[$identifier_r[0]][] = $k;
+				$key_sets[$identifier_r[$position]][] = $k;
 			}
 		}
 		else
