@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2016, Phoronix Media
-	Copyright (C) 2008 - 2016, Michael Larabel
+	Copyright (C) 2008 - 2017, Phoronix Media
+	Copyright (C) 2008 - 2017, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -26,11 +26,22 @@ class pts_user_io
 	{
 		return trim(fgets(STDIN));
 	}
+	public static function strip_ansi_escape_sequences($output)
+	{
+		if(function_exists('preg_replace'))
+		{
+			$output = preg_replace('/\x1b(\[|\(|\))[;?0-9]*[0-9A-Za-z]/', null, $output);
+			$output = preg_replace('/\x1b(\[|\(|\))[;?0-9]*[0-9A-Za-z]/', null, $output);
+			$output = preg_replace('/[\x03|\x1a]/', null, $output);
+		}
+
+		return $output;
+	}
 	public static function prompt_user_input($question, $allow_null = false)
 	{
 		do
 		{
-			echo PHP_EOL . $question . ': ';
+			echo PHP_EOL . pts_client::cli_just_bold($question . ': ');
 			$answer = pts_user_io::read_user_input();
 		}
 		while(!$allow_null && empty($answer));
@@ -48,7 +59,7 @@ class pts_user_io
 
 		return $list;
 	}
-	public static function display_text_table(&$table, $prepend_to_lines = null, $extra_width_to_column = 0)
+	public static function display_text_table(&$table, $prepend_to_lines = null, $extra_width_to_column = 0, $min_width = 0)
 	{
 		$column_widths = array();
 		$formatted_table = $prepend_to_lines;
@@ -72,7 +83,7 @@ class pts_user_io
 
 				if(($c + 1) != $rc_count)
 				{
-					$formatted_table .= str_repeat(' ', (1 + $extra_width_to_column + $column_widths[$c] - strlen($table[$r][$c])));
+					$formatted_table .= str_repeat(' ', (max($min_width, 1 + $extra_width_to_column + $column_widths[$c]) - strlen($table[$r][$c])));
 				}
 			}
 
@@ -102,7 +113,7 @@ class pts_user_io
 
 		do
 		{
-			pts_client::$display->generic_prompt($question);
+			pts_client::$display->generic_prompt(pts_client::cli_just_bold($question));
 			$input = strtolower(pts_user_io::read_user_input());
 		}
 		while($input != 'y' && $input != 'n' && $input != '');
@@ -138,9 +149,9 @@ class pts_user_io
 			foreach(array_keys($options_r) as $i => $key)
 			{
 				$key_index[($i + 1)] = $key;
-				echo $line_prefix . ($i + 1) . ': ' . str_repeat(' ', strlen($option_count) - strlen(($i + 1))) . $options_r[$key] . PHP_EOL;
+				echo $line_prefix . pts_client::cli_just_bold(($i + 1) . ': ') . str_repeat(' ', strlen($option_count) - strlen(($i + 1))) . $options_r[$key] . PHP_EOL;
 			}
-			echo $line_prefix . $user_string . ': ';
+			echo $line_prefix . pts_client::cli_just_bold($user_string . ': ');
 			$select_choice = pts_user_io::read_user_input();
 
 			foreach(($allow_multi_select ? pts_strings::comma_explode($select_choice) : array($select_choice)) as $choice)
